@@ -15,36 +15,23 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-"""Rules-based Policy Engine."""
+"""Policy engine for keystone"""
 
 import os.path
 
-from keystone.common import logging
-from keystone.common import policy as common_policy
 from keystone.common import utils
 from keystone import config
 from keystone import exception
-from keystone.openstack.common import cfg
+from keystone.openstack.common import log as logging
+from keystone.openstack.common import policy as common_policy
 from keystone import policy
 
 
-policy_opts = [
-    cfg.StrOpt('policy_file',
-               default='policy.json',
-               help=_('JSON file representing policy')),
-    cfg.StrOpt('policy_default_rule',
-               default='default',
-               help=_('Rule checked when requested rule is not found')),
-]
-
-
 CONF = config.CONF
-CONF.register_opts(policy_opts)
-
-
 LOG = logging.getLogger(__name__)
 
 
+_ENFORCER = None
 _POLICY_PATH = None
 _POLICY_CACHE = {}
 
@@ -52,59 +39,65 @@ _POLICY_CACHE = {}
 def reset():
     global _POLICY_PATH
     global _POLICY_CACHE
+    global _ENFORCER
     _POLICY_PATH = None
     _POLICY_CACHE = {}
-    common_policy.reset()
+    _ENFORCER = None
 
 
 def init():
     global _POLICY_PATH
     global _POLICY_CACHE
+    global _ENFORCER
     if not _POLICY_PATH:
         _POLICY_PATH = CONF.policy_file
         if not os.path.exists(_POLICY_PATH):
             _POLICY_PATH = CONF.find_file(_POLICY_PATH)
+    if not _ENFORCER:
+        _ENFORCER = common_policy.Enforcer(policy_file=_POLICY_PATH)
     utils.read_cached_file(_POLICY_PATH,
                            _POLICY_CACHE,
-                           reload_func=_set_brain)
+                           reload_func=_set_rules)
 
 
-def _set_brain(data):
+def _set_rules(data):
+    global _ENFORCER
     default_rule = CONF.policy_default_rule
-    common_policy.set_brain(common_policy.HttpBrain.load_json(data,
-                                                              default_rule))
+    _ENFORCER.set_rules(common_policy.Rules.load_json(
+        data, default_rule))
 
 
-def enforce(credentials, action, target):
+def enforce(credentials, action, target, do_raise=True):
     """Verifies that the action is valid on the target in this context.
 
        :param credentials: user credentials
-       :param action: string representing the action to be checked
-
-           this should be colon separated for clarity.
-           i.e. compute:create_instance
-                compute:attach_volume
-                volume:attach_volume
-
+       :param action: string representing the action to be checked, which
+                      should be colon separated for clarity.
        :param target: dictionary representing the object of the action
                       for object creation this should be a dictionary
                       representing the location of the object e.g.
-                      {'tenant_id': object.tenant_id}
-
+                      {'project_id': object.project_id}
        :raises: `exception.Forbidden` if verification fails.
 
+       Actions should be colon separated for clarity. For example:
+
+        * identity:list_users
+
     """
     init()
 
-    match_list = ('rule:%s' % action,)
+    # Add the exception arguments if asked to do a raise
+    extra = {}
+    if do_raise:
+        extra.update(exc=exception.ForbiddenAction, action=action,
+                     do_raise=do_raise)
 
-    try:
-        common_policy.enforce(match_list, target, credentials)
-    except common_policy.NotAuthorized:
-        raise exception.ForbiddenAction(action=action)
+    return _ENFORCER.enforce(action, target, credentials, **extra)
 
 
 class Policy(policy.Driver):
     def enforce(self, credentials, action, target):
-        LOG.debug('enforce %s: %s', action, credentials)
+        LOG.debug(_('enforce %(action)s: %(credentials)s') % {
+            'action': action,
+            'credentials': credentials})
         enforce(credentials, action, target)
