@@ -1,6 +1,6 @@
 # vim: tabstop=4 shiftwidth=4 softtabstop=4
 
-# Copyright 2012 OpenStack LLC
+# Copyright 2012 OpenStack Foundation
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
@@ -26,11 +26,11 @@ class TrustModel(sql.ModelBase, sql.DictBase):
                   'project_id', 'impersonation', 'expires_at']
     id = sql.Column(sql.String(64), primary_key=True)
     #user id Of owner
-    trustor_user_id = sql.Column(sql.String(64), unique=False, nullable=False,)
+    trustor_user_id = sql.Column(sql.String(64), nullable=False,)
     #user_id of user allowed to consume this preauth
-    trustee_user_id = sql.Column(sql.String(64), unique=False, nullable=False)
-    project_id = sql.Column(sql.String(64), unique=False, nullable=True)
-    impersonation = sql.Column(sql.Boolean)
+    trustee_user_id = sql.Column(sql.String(64), nullable=False)
+    project_id = sql.Column(sql.String(64))
+    impersonation = sql.Column(sql.Boolean, nullable=False)
     deleted_at = sql.Column(sql.DateTime)
     expires_at = sql.Column(sql.DateTime)
     extra = sql.Column(sql.JsonBlob())
@@ -114,10 +114,8 @@ class Trust(sql.Base, trust.Driver):
     def delete_trust(self, trust_id):
         session = self.get_session()
         with session.begin():
-            try:
-                trust_ref = (session.query(TrustModel).
-                             filter_by(id=trust_id).one())
-            except sql.NotFound:
+            trust_ref = session.query(TrustModel).get(trust_id)
+            if not trust_ref:
                 raise exception.TrustNotFound(trust_id=trust_id)
             trust_ref.deleted_at = timeutils.utcnow()
             session.flush()
